@@ -583,7 +583,7 @@ MagickPrivate char *FileToXML(const char *filename,const size_t extent)
           break;
       }
       if (LocaleCompare(filename,"-") != 0)
-        file=close(file);
+        file=close_utf8(file);
       if (xml == (char *) NULL)
         return((char *) NULL);
       if (file == -1)
@@ -601,7 +601,7 @@ MagickPrivate char *FileToXML(const char *filename,const size_t extent)
     xml=(char *) AcquireQuantumMemory(length+MagickPathExtent,sizeof(*xml));
   if (xml == (char *) NULL)
     {
-      file=close(file);
+      file=close_utf8(file);
       return((char *) NULL);
     }
   map=MapBlob(file,ReadMode,0,length);
@@ -626,14 +626,14 @@ MagickPrivate char *FileToXML(const char *filename,const size_t extent)
       }
       if (i < length)
         {
-          file=close(file)-1;
+          file=close_utf8(file)-1;
           xml=(char *) RelinquishMagickMemory(xml);
           return((char *) NULL);
         }
     }
   xml[length]='\0';
   if (LocaleCompare(filename,"-") != 0)
-    file=close(file);
+    file=close_utf8(file);
   if (file == -1)
     xml=(char *) RelinquishMagickMemory(xml);
   return(xml);
@@ -1256,7 +1256,7 @@ static char *ConvertUTF16ToUTF8(const char *content,size_t *length)
       }
     if (c < 0x80)
       {
-        utf8[j]=c;
+        utf8[j]=(char) c;
         j++;
         continue;
       }
@@ -1267,7 +1267,7 @@ static char *ConvertUTF16ToUTF8(const char *content,size_t *length)
     for (bits=0; byte != 0; byte/=2)
       bits++;
     bits=(bits-2)/5;
-    utf8[j++]=(0xFF << (7-bits)) | (c >> (6*bits));
+    utf8[j++]=(char) ((0xFF << (7-bits)) | (c >> (6*bits)));
     while (bits != 0)
     {
       bits--;
@@ -1346,7 +1346,7 @@ static char *ParseEntities(char *xml,char **entities,int state)
             continue;
           }
         if (c < 0x80)
-          *(xml++)=c;
+          *(xml++)=(char) c;
         else
           {
             /*
@@ -1938,7 +1938,7 @@ MagickExport XMLTreeInfo *NewXMLTree(const char *xml,ExceptionInfo *exception)
             utf8=DestroyString(utf8);
             return(&root->root);
           }
-        p+=strcspn(p,XMLWhitespace "/>");
+        p+=(ptrdiff_t) strcspn(p,XMLWhitespace "/>");
         while (isspace((int) ((unsigned char) *p)) != 0)
           *p++='\0';
         if (((isalpha((int) ((unsigned char) *p)) != 0) || (*p == '_')) &&
@@ -1976,13 +1976,13 @@ MagickExport XMLTreeInfo *NewXMLTree(const char *xml,ExceptionInfo *exception)
               attributes[l+2]=(char *) NULL;
               attributes[l+1]=(char *) NULL;
               attributes[l]=p;
-              p+=strcspn(p,XMLWhitespace "=/>");
+              p+=(ptrdiff_t) strcspn(p,XMLWhitespace "=/>");
               if ((*p != '=') && (isspace((int) ((unsigned char) *p)) == 0))
                 attributes[l]=ConstantString("");
               else
                 {
                   *p++='\0';
-                  p+=strspn(p,XMLWhitespace "=");
+                  p+=(ptrdiff_t) strspn(p,XMLWhitespace "=");
                   c=(*p);
                   if ((c == '"') || (c == '\''))
                     {
@@ -2064,7 +2064,7 @@ MagickExport XMLTreeInfo *NewXMLTree(const char *xml,ExceptionInfo *exception)
                     ignore_depth++;
                     (void) DestroyXMLTreeAttributes(attributes);
                   }
-                *p=c;
+                *p=(char) c;
               }
             else
               {
@@ -2084,7 +2084,7 @@ MagickExport XMLTreeInfo *NewXMLTree(const char *xml,ExceptionInfo *exception)
             Close tag.
           */
           tag=p+1;
-          p+=strcspn(tag,XMLWhitespace ">")+1;
+          p+=(ptrdiff_t) strcspn(tag,XMLWhitespace ">")+1;
           c=(*p);
           if ((c == '\0') && (terminal != '>'))
             {
@@ -2102,9 +2102,9 @@ MagickExport XMLTreeInfo *NewXMLTree(const char *xml,ExceptionInfo *exception)
             }
           if (ignore_depth > 0)
             ignore_depth--;
-          *p=c;
+          *p=(char) c;
           if (isspace((int) ((unsigned char) *p)) != 0)
-            p+=strspn(p,XMLWhitespace);
+            p+=(ptrdiff_t) strspn(p,XMLWhitespace);
         }
       else
         if (strncmp(p,"!--",3) == 0)
@@ -2131,7 +2131,7 @@ MagickExport XMLTreeInfo *NewXMLTree(const char *xml,ExceptionInfo *exception)
               p=strstr(p,"]]>");
               if (p != (char *) NULL)
                 {
-                  p+=2;
+                  p+=(ptrdiff_t) 2;
                   if (ignore_depth == 0)
                     ParseCharacterContent(root,tag+8,(size_t) (p-tag-10),'c');
                 }
@@ -2153,7 +2153,7 @@ MagickExport XMLTreeInfo *NewXMLTree(const char *xml,ExceptionInfo *exception)
                      ((l != 0) && ((*p != ']') ||
                      (*(p+strspn(p+1,XMLWhitespace)+1) != '>'))));
                   l=(ssize_t) ((*p == '[') ? 1 : l))
-                p+=strcspn(p+1,"[]>")+1;
+                p+=(ptrdiff_t) strcspn(p+1,"[]>")+1;
                 if ((*p == '\0') && (terminal != '>'))
                   {
                     (void) ThrowMagickException(exception,GetMagickModule(),
